gpmp is mainly developed and maintained by:

 * Emmanuel VAZQUEZ

The following people have helped develop the package in various ways
(from providing ideas and bug reports to actually contributing code):

 * Julien BECT
 * Sébastien PETIT
